@@ -1,23 +1,26 @@
 # -*- coding: utf-8 -*-
 
 
-"""
-proxyapi.requestsproxies
-~~~~~~~~~~~~~~
-
-This module provides a proxy dictionary for the requests library.
-"""
+"""This module provides a proxy dictionary for the requests library."""
 
+import json
 from .generators import get_http_proxy, get_https_proxy
+from .generators import get_http_proxy_from_json, get_https_proxy_from_json
 
 
 class RequestsProxies(object):
 
     """A RequestsProxies dictionary."""
 
-    def __init__(self, url='http://proxyapi.davidxia.com/'):
-        self.http_proxy_gen = get_http_proxy(url)
-        self.https_proxy_gen = get_https_proxy(url)
+    def __init__(self, file_path=None, url='http://proxyapi.davidxia.com/'):
+        if file_path is not None:
+            with open(file_path) as f:
+                json_data = json.load(f)
+            self.http_proxy_gen = get_http_proxy_from_json(json_data)
+            self.https_proxy_gen = get_https_proxy_from_json(json_data)
+        else:
+            self.http_proxy_gen = get_http_proxy(url)
+            self.https_proxy_gen = get_https_proxy(url)
 
         self.proxies = {}
         self.next_http_proxy()
